package com.fs.store.service;

import java.util.List;
import com.fs.store.domain.FsStoreOrderOfflineItem;

/**
 * 线下订单详情Service接口
 *
 * @author fs
 * @date 2024-10-29
 */
public interface IFsStoreOrderOfflineItemService
{
    /**
     * 查询线下订单详情
     *
     * @param itemId 线下订单详情ID
     * @return 线下订单详情
     */
    public FsStoreOrderOfflineItem selectFsStoreOrderOfflineItemById(Long itemId);

    /**
     * 查询线下订单详情列表
     *
     * @param fsStoreOrderOfflineItem 线下订单详情
     * @return 线下订单详情集合
     */
    public List<FsStoreOrderOfflineItem> selectFsStoreOrderOfflineItemList(FsStoreOrderOfflineItem fsStoreOrderOfflineItem);

    /**
     * 新增线下订单详情
     *
     * @param fsStoreOrderOfflineItem 线下订单详情
     * @return 结果
     */
    public int insertFsStoreOrderOfflineItem(FsStoreOrderOfflineItem fsStoreOrderOfflineItem);

    /**
     * 修改线下订单详情
     *
     * @param fsStoreOrderOfflineItem 线下订单详情
     * @return 结果
     */
    public int updateFsStoreOrderOfflineItem(FsStoreOrderOfflineItem fsStoreOrderOfflineItem);

    /**
     * 批量删除线下订单详情
     *
     * @param itemIds 需要删除的线下订单详情ID
     * @return 结果
     */
    public int deleteFsStoreOrderOfflineItemByIds(Long[] itemIds);

    /**
     * 删除线下订单详情信息
     *
     * @param itemId 线下订单详情ID
     * @return 结果
     */
    public int deleteFsStoreOrderOfflineItemById(Long itemId);
}
