package com.fs.store.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.fs.common.annotation.Log;
import com.fs.common.core.controller.BaseController;
import com.fs.common.core.domain.AjaxResult;
import com.fs.common.enums.BusinessType;
import com.fs.store.domain.FsStoreOrderOfflineItem;
import com.fs.store.service.IFsStoreOrderOfflineItemService;
import com.fs.common.utils.poi.ExcelUtil;
import com.fs.common.core.page.TableDataInfo;

/**
 * 线下订单详情Controller
 *
 * @author fs
 * @date 2024-10-29
 */
@RestController
@RequestMapping("/storeOrderOfflineItem/store")
public class FsStoreOrderOfflineItemController extends BaseController
{
    @Autowired
    private IFsStoreOrderOfflineItemService fsStoreOrderOfflineItemService;

    /**
     * 查询线下订单详情列表
     */
    @PreAuthorize("@ss.hasPermi('storeOrderOfflineItem:store:list')")
    @GetMapping("/list")
    public TableDataInfo list(FsStoreOrderOfflineItem fsStoreOrderOfflineItem)
    {
        startPage();
        List<FsStoreOrderOfflineItem> list = fsStoreOrderOfflineItemService.selectFsStoreOrderOfflineItemList(fsStoreOrderOfflineItem);
        return getDataTable(list);
    }

    /**
     * 导出线下订单详情列表
     */
    @PreAuthorize("@ss.hasPermi('storeOrderOfflineItem:store:export')")
    @Log(title = "线下订单详情", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(FsStoreOrderOfflineItem fsStoreOrderOfflineItem)
    {
        List<FsStoreOrderOfflineItem> list = fsStoreOrderOfflineItemService.selectFsStoreOrderOfflineItemList(fsStoreOrderOfflineItem);
        ExcelUtil<FsStoreOrderOfflineItem> util = new ExcelUtil<FsStoreOrderOfflineItem>(FsStoreOrderOfflineItem.class);
        return util.exportExcel(list, "store");
    }

    /**
     * 获取线下订单详情详细信息
     */
    @PreAuthorize("@ss.hasPermi('storeOrderOfflineItem:store:query')")
    @GetMapping(value = "/{itemId}")
    public AjaxResult getInfo(@PathVariable("itemId") Long itemId)
    {
        return AjaxResult.success(fsStoreOrderOfflineItemService.selectFsStoreOrderOfflineItemById(itemId));
    }

    /**
     * 新增线下订单详情
     */
    @PreAuthorize("@ss.hasPermi('storeOrderOfflineItem:store:add')")
    @Log(title = "线下订单详情", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FsStoreOrderOfflineItem fsStoreOrderOfflineItem)
    {
        return toAjax(fsStoreOrderOfflineItemService.insertFsStoreOrderOfflineItem(fsStoreOrderOfflineItem));
    }

    /**
     * 修改线下订单详情
     */
    @PreAuthorize("@ss.hasPermi('storeOrderOfflineItem:store:edit')")
    @Log(title = "线下订单详情", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody FsStoreOrderOfflineItem fsStoreOrderOfflineItem)
    {
        return toAjax(fsStoreOrderOfflineItemService.updateFsStoreOrderOfflineItem(fsStoreOrderOfflineItem));
    }

    /**
     * 删除线下订单详情
     */
    @PreAuthorize("@ss.hasPermi('storeOrderOfflineItem:store:remove')")
    @Log(title = "线下订单详情", businessType = BusinessType.DELETE)
	@DeleteMapping("/{itemIds}")
    public AjaxResult remove(@PathVariable Long[] itemIds)
    {
        return toAjax(fsStoreOrderOfflineItemService.deleteFsStoreOrderOfflineItemByIds(itemIds));
    }
}
